===================
django-github-storage
===================

A lightweight authentication and access management library for integration with OpenID Connect enabled authentication services.


Documentation
-------------

The full documentation is at `<https://django-github-storage.readthedocs.io>`_.


Description
-----------------

The Module use github as storage, backup images and media files in github.



License
-------

This software is licensed under the MPL 2.0 license. For more info check the LICENSE file.


